import setuptools 
from setuptools import setup
setup(
      name='jdOctopus',
      version='0.3',
      description='jd-octopus py version',
      url='http://dqa.jd.com/octopus',
      author='renran',
      author_email='1114802403@qq.com',
      license='MIT',
      packages=setuptools.find_packages(),
      zip_safe=False,
      )